@@ -1,12 +1,16 @@
 import json
+import os
 from typing import Any
 
 filename = "store.json"
+dir_path = os.path.dirname(os.path.realpath(__file__)).split("/utils")[0]
+
+file_path = f"{dir_path}/{filename}"
 
 
 def read_field(key: str) -> Any:
     try:
-        with open(filename, "r") as f:
+        with open(file_path, "r") as f:
             fields = json.loads(f.read())
             return fields.get(key, None)
     except:
@@ -15,7 +19,7 @@ def read_field(key: str) -> Any:
 
 def set_field(key: str, value: Any) -> None:
     try:
-        with open(filename, "r") as f:
+        with open(file_path, "r") as f:
             try:
                 fields = json.loads(f.read())
             except:
@@ -23,7 +27,7 @@ def set_field(key: str, value: Any) -> None:
             f.close()
     except:
         fields = {}
-    with open(filename, "w+") as f:
+    with open(file_path, "w+") as f:
         fields[key] = value
         data = json.dumps(fields)
         f.write(data)
@@ -32,7 +36,7 @@ def set_field(key: str, value: Any) -> None:
 
 
 def unset_field(key: str) -> None:
-    with open(filename, "w+") as f:
+    with open(file_path, "w+") as f:
         try:
             fields = json.loads(f.read())
         except:
